# RLB Core

Implements functionality common among all RLBaselines projects.

All RLBaselines projects have `rlbcore` as a dependency.

## Python environment

Create your python environment using `poetry install -E all`

### Useful resources

1. [Material for MkDocs](https://jamstackthemes.dev/demo/theme/mkdocs-material/)
2. [MkDocs](https://www.mkdocs.org/)
3. [Blog post](https://blog.elmah.io/creating-a-documentation-site-with-mkdocs/)
